@@ -1,17 +1,10 @@
-from typing import Callable, List, Optional, Union
+from typing import Callable, List
 
-from discord import Embed, Emoji, PartialEmoji
-
-Callback = Optional[Callable]
-ButtonList = List[Union[str, Emoji, PartialEmoji]]
+from discord import Embed
 
 
 class Page(Embed):
-    """Represents a single page inside a menu.
-
-    Attributes
-        :embed: A discord Embed object. Used in place of utilizing the Page as an Embed object itself.
-    """
+    """Represents a single page inside a menu."""
 
     __slots__ = (*Embed.__slots__, '_index', '_buttons_list', '_on_next_event', '_on_fail_event', '_on_cancel_event', '_on_timeout_event')
 
